#*********************BlobbyMan.py*************************
#
#   William Baker
#   Ryan Mulligan
#
#   usage:  should not be used directly. 
#           import BlobbyMan 
#
#   Blobby man is back in Box form.  Packaged as a primative for gvportage
#
#
#*********************************************************

from math import *
from gvportage import *
from threading import Thread

def to_rad(degrees):
	return (pi/180)*degrees

class BlobbyMan:
	def __init__(self, transform_frame):
		self.world_fr=frame(frame=transform_frame)
		self.human_fr=frame(frame=self.world_fr)
		self.head_fr=frame(frame=self.human_fr)
		self.luarm_fr=frame(frame=self.human_fr)
		self.lfarm_fr=frame(frame=self.luarm_fr)
		self.lhand_fr=frame(frame=self.lfarm_fr)
		self.ruarm_fr=frame(frame=self.human_fr)
		self.rfarm_fr=frame(frame=self.ruarm_fr)
		self.rhand_fr=frame(frame=self.rfarm_fr)
		self.luleg_fr=frame(frame=self.human_fr)
		self.ruleg_fr=frame(frame=self.human_fr)
		self.llleg_fr=frame(frame=self.luleg_fr)
		self.rlleg_fr=frame(frame=self.ruleg_fr)
		self.lfoot_fr=frame(frame=self.llleg_fr)
		self.rfoot_fr=frame(frame=self.rlleg_fr)
		
		# Initialize body parts in their correct frames
		torso = box(frame=self.human_fr,pos=(0,0,0), length=1, height=2.5, width=.5,
						color=(.2,.2,.9))
		
		head = box(frame=self.head_fr,pos=(0,.5,0), length=.8, height=1, width=.75,
						color=(.2,.2,.9))
		
		luarm = box(frame=self.luarm_fr, pos=(.5,0,0), length=1, height=.3, width=.1,
						color=(.2,.2,.9))
		
		ruarm = box(frame=self.ruarm_fr, pos=(-.5,0,0), length=1, height=.3, 
						width=.1,color=(.2,.2,.9))
		
		lfarm = box(frame=self.lfarm_fr, pos=(.5,0,0), length=1, height=.3, width=.1,
						color=(.2,.2,.9))
		
		rfarm = box(frame=self.rfarm_fr, pos=(-.5,0,0), length=1, height=.3, 
						width=.1,color=(.2,.2,.9))
		
		lhand = box(frame=self.lhand_fr, pos=(.25,0,0), length=.45, height=.3, 
						width=.1,color=(.2,.2,.9))
		
		rhand = box(frame=self.rhand_fr, pos=(-.25,0,0), length=.45, height=.3, 
						width=.1,color=(.2,.2,.9))
		
		luleg = box(frame=self.luleg_fr, pos=(0,-.75,0), length=.5, height=1.5, 
						width=.3, color=(.2,.2,.9))
		
		ruleg = box(frame=self.ruleg_fr, pos=(0,-.75,0), length=.5, height=1.5, 
						width=.3, color=(.2,.2,.9))
		
		llleg = box(frame=self.llleg_fr, pos=(0,-.75,0), length=.5, height=1.5, 
						width=.3, color=(.2,.2,.9))
		
		rlleg = box(frame=self.rlleg_fr, pos=(0,-.75,0), length=.5, height=1.5, 
						width=.3, color=(.2,.2,.9))
		
		lfoot = box(frame=self.lfoot_fr, pos=(.25,0,0), length=.45, height=.1, 
						width=.3,color=(.2,.2,.9))
		
		rfoot = box(frame=self.rfoot_fr, pos=(-.25,0,0), length=.45, height=.1, 
						width=.3,color=(.2,.2,.9))
		
		# Move the frames to their correct starting locations (i.e. glTranslate)
		# All .pos are relative to the frame that they are in
		self.world_fr.pos=(0,0,0)
		self.human_fr.pos=(0,0,0)
		self.head_fr.pos=(0,1.3,0)
		self.luarm_fr.pos=(.55,1.1,0)
		self.ruarm_fr.pos=(-.55,1.1,0)
		self.lfarm_fr.pos=(1.05,0,0)
		self.rfarm_fr.pos=(-1.05,0,0)
		self.lhand_fr.pos=(1.0,0,0)
		self.rhand_fr.pos=(-1.0,0,0)
		self.luleg_fr.pos=(.35,-1.3,0)
		self.ruleg_fr.pos=(-.35,-1.3,0)
		self.llleg_fr.pos=(0,-1.6,0)
		self.rlleg_fr.pos=(0,-1.6,0)
		self.lfoot_fr.pos=(0,-1.6,0)
		self.rfoot_fr.pos=(0,-1.6,0)
		
		self.animation_state = 0;
  
	#does one frame of animation every time it is called.
	def one_frame(self):
		if (self.animation_state < 0):
			pass
		elif (self.animation_state == 0):
			self.luarm_fr.rotate( angle = to_rad(45), axis = (0, 0, 1))
		elif (self.animation_state == 1):
			self.lfarm_fr.rotate( angle = to_rad(45), axis = (0, 0, 1))
		elif (self.animation_state == 2):
		  pass
		elif (self.animation_state >= 3 and self.animation_state < 5):
			self.lhand_fr.rotate( angle = to_rad(20), axis = (0, 0, 1))
		elif (self.animation_state >= 5 and self.animation_state < 9):
			self.lhand_fr.rotate( angle = to_rad(-20), axis = (0, 0, 1))
		elif (self.animation_state >= 9 and self.animation_state < 11):
			self.lhand_fr.rotate( angle = to_rad(20), axis = (0, 0, 1))
		elif (self.animation_state == 11):
			self.lfarm_fr.rotate( angle = to_rad(-45), axis = (0, 0, 1))
		elif (self.animation_state == 12):
			self.luarm_fr.rotate( angle = to_rad(-45), axis = (0, 0, 1))
		else:
		  self.animation_state = -3
		self.animation_state += 1
